@@ -1,11 +1,11 @@
 library(testit)
 
-assert('assert works', 1==1)
+assert('assert works', 1 == 1)
 
 # Okay, that is kind of cheating
 assert(
   'assert() should signal an error if a condition does not hold',
-  has_error(assert('this should produce an error', 1==2))
+  has_error(assert('this should produce an error', 1 == 2))
 )
 
 # a meaningless test in terms of R (failure is irrelevant to Frequentist or Bayesian)
@@ -36,3 +36,14 @@ assert(
   has_error(stop('An intentional error')),
   has_error(1 + 'a')
 )
+
+assert('tests can be written in () in a single {}', {
+
+  (1 == 1L)
+
+  z = 1:10
+  (rev(z) %==% 10:1)
+
+  !!TRUE
+
+})
